# 2020-12-03 - Batch Relayer

> ⚠️ **DEPRECATED: do not use** ⚠️
>
> This relayer was superseded by an [updated version (also now deprecated)](../20220720-batch-relayer-v3) with more features.

Deployment of the first `BalancerRelayer` using `BatchRelayerLibrary`, for combining multiple operations (swaps, joins, etc.) in a single transaction.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Polygon mainnet address](./output/polygon.json)
- [Arbitrum mainnet address](./output/arbitrum.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`BatchRelayerLibrary` artifact](./artifact/BatchRelayerLibrary.json)
